DCE plugin for Quantiphyse
==========================

This plugin provides modelling tools for DCE-MRI. Currently
two implementations are provided - one based on the Tofts-Orton
model and one using the Fabber Bayesian model fitting tool which
supports both measured and population AIFs

Quantiphyse and quantiphyse-fabber must be installed. To
install the DCE plugin from PyPi use:

    pip install quantiphyse-dce

The plugin will then be available from within Quantiphyse

